/**
 * @name laravel-elixir-sassdoc
 * @author Shane Hendrix
 *
 * @desc Generate documentation for SASS files
 *
 * {@link https://github.com/SassDoc/sassdoc link}
 *
 * @requires sassdoc
 */

/*global require */


var gulp    = require('gulp'),
    Elixir  = require('laravel-elixir'),
    sassdoc = require('sassdoc'),
    del     = require('del');

var notify = new Elixir.Notification();

/*
 |----------------------------------------------------------------
 | SASSDOC
 |----------------------------------------------------------------
 |
 | This task triggers the SASSDOC software and shows
 | notifications depending on the success or the
 | failure of the SASSDOC via elixir software
 |
 */

Elixir.extend('sassdoc', function initSASSDOC (src, options) {
    'use strict';

    var name        = 'SASSDOC',
        defaultDest = './storage/reports/sassdoc';

    // CHECK:       Options is set
    options = options || {};

    // CHECK:       Destination
    options.dest = options.dest || defaultDest;


    var onError = function onErrorFunction (err) {
        notify.error(err, `${name} error!`);
        this.emit('end');
    };

    // ADD:     Elixir Task
    new Elixir.Task('sassdoc', function elixirSassDocTask () {  // eslint-disable-line no-new
        // CLEAN:       Destination
        del([options.dest]);

        // RUN:         SASSDOC task
        return gulp
            .src(src || Elixir.config.get('assets.css.sass.folder') + '/**/*.scss')
            .pipe(sassdoc(options))
            .on('error', onError)
            .pipe(new Elixir.Notification(`${name} completed`))
            .resume()
            ;
    });
});
